@@ -4,7 +4,7 @@ from neighborhood_analysis import CellCombs, get_neighbors, comb_bootstrap
 
 from time import time
 
-types = ['a', 'b', 'c', 'd', 'e', 'f', 'aa', 'cc', 'dd']
+types = ['a', 'b', 'c', 'd', 'e']
 points = np.random.randint(0, 1000, (10000, 2))
 corr_types = np.random.choice(types, 10000)
 points = [(x, y) for (x, y) in points]
@@ -13,6 +13,12 @@ neighbors = get_neighbors(points, 10.0)
 start = time()
 cc = CellCombs(types)
 cc.bootstrap(corr_types, neighbors, ignore_self=True)
+print("order=False:", cc.cell_combs)
+
+cc = CellCombs(types, True)
+cc.bootstrap(corr_types, neighbors, ignore_self=True)
+print("order=True:", cc.cell_combs)
+
 end = time()
 print(f"used {(end-start):.2f}s")
 
